OC.L10N.register(
    "spreed",
    {
    "a conversation" : "en konversation",
    "(Duration %s)" : "(Varaktighet%s)",
    "You attended a call with {user1}" : "Du deltog i ett samtal med {user1}",
    "_%n guest_::_%n guests_" : ["%n gäst","%n gäster"],
    "You attended a call with {user1} and {user2}" : "Du deltog i ett samtal med {user1} och {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Du deltog i ett samtal med {user1}, {user2} och {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Du deltog i ett samtal med {user1}, {user2}, {user3} och {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Du deltog i ett samtal med {user1}, {user2}, {user3}, {user4} och {user5}",
    "_%n other_::_%n others_" : ["%n annan","%n andra"],
    "{actor} invited you to {call}" : "{actor} bjöd in dig till {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Du blev inbjuden till en <strong>konversation</strong> eller hade ett <strong>samtal</strong>",
    "Talk" : "Talk",
    "Guest" : "Gäst",
    "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Välkommen till Nextcloud Talk!\nI denna konversation kommer du att bli informerad om nya funktioner som finns i Nextcloud Talk.",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge och Safari kan nu användas för att delta i ljud- och videosamtal",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Du kan nu meddela alla deltagare genom att skicka \"@all\" till chatten",
    "- With the \"arrow-up\" key you can repost your last message" : "- Med \"pil upp\" -knappen kan du skicka om ditt senaste meddelande",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk kan nu ha kommandon, skicka \"/help\" som ett chattmeddelande för att se om din administratör har konfigurerat några",
    "- With projects you can create quick links between conversations, files and other items" : "- Med projekt kan du skapa snabba länkar mellan konversationer, filer och andra objekt",
    "- You can now mention guests in the chat" : "- Du kan nu nämna gäster i chatten",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Konversationer kan nu ha en lobby. Detta gör att moderatorer nu kan förbereda mötet, medan användare och gäster måste vänta.",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Du kan nu svara direkt på meddelanden som ger de andra användarna mer sammanhang vad ditt meddelande handlar om",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Sökning efter konversationer och deltagare kommer nu också att filtrera dina befintliga konversationer, vilket gör det mycket lättare att hitta tidigare konversationer",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Du kan nu lägga till anpassade användargrupper i konversationer när cirkelappen är installerad",
    "- Check out the new grid and call view" : "- Kolla in det nya gränssnittet och samtals-vyn",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Nu går det att ladda upp filer direkt med drag'n'drop från din enhet  till chatten",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Delade filer visas nu direkt inuti chatten och öppnas med rätt applikation.",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Nu kan du söka efter chattar och meddelanden gemensamt från sökrutan i menyn",
    "- Spice up your messages with emojis from the emoji picker" : "- Snygga till dina meddelanden med emojis",
    "- You can now change your camera and microphone while being in a call" : "- Nu går det att ändra kameran och mikrofonen medans du sitter i ett samtal",
    "- Raise your hand in a call with the R key" : "- Lyft handen i ett samtal med R-tangenten",
    "There are currently no commands available." : "Det finns för närvarande inga kommandon tillgängliga.",
    "The command does not exist" : "Kommandot finns inte",
    "An error occurred while running the command. Please ask an administrator to check the logs." : "Ett fel inträffade under körning av kommandot. Be en administratör att kontrollera loggarna.",
    "Talk updates ✅" : "Talk-uppdateringar ✅",
    "{actor} created the conversation" : "{actor} skapade konversationen",
    "You created the conversation" : "Du skapade konversationen",
    "An administrator created the conversation" : "En administratör skapade konversationen",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} bytte namn på konversationen från \"%1$s\" till \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Du bytte namn på konversationen från \"%1$s\" till \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "En administratör döpte om konversationen från \"%1$s\" till \"%2$s\"",
    "{actor} removed the description" : "{actor} tog bort beskrivningen",
    "You removed the description" : "Du tog bort beskrivningen",
    "An administrator removed the description" : "En administratör tog bort beskrivningen",
    "{actor} started a call" : "{actor} startade ett samtal",
    "You started a call" : "Du startade ett samtal",
    "{actor} joined the call" : "{actor} gick med i samtalet",
    "You joined the call" : "Du gick med i samtalet",
    "{actor} left the call" : "{actor} lämnade samtalet",
    "You left the call" : "Du lämnade samtalet",
    "{actor} unlocked the conversation" : "{actor} låste upp konversationen",
    "You unlocked the conversation" : "Du låste upp konversationen",
    "An administrator unlocked the conversation" : "En administratör låste upp konversationen",
    "{actor} locked the conversation" : "{actor} låste konversationen",
    "You locked the conversation" : "Du låste konversationen",
    "An administrator locked the conversation" : "En administratör låste konversationen",
    "{actor} opened the conversation to registered users" : "{actor} öppnade konversationen för registrerade användare",
    "You opened the conversation to registered users" : "Du öppnade konversationen för registrerade användare",
    "An administrator opened the conversation to registered users" : "En administratör öppnade konversationen för registrerade användare",
    "{actor} opened the conversation to registered and guest app users" : "{actor} öppnade konversationen för registrerade och gästappanvändare",
    "You opened the conversation to registered and guest app users" : "Du öppnade konversationen för registrerade och gästappanvändare",
    "An administrator opened the conversation to registered and guest app users" : "En administratör öppnade konversationen för registrerade och gästappsanvändare",
    "The conversation is now open to everyone" : "Konversationen är nu öppen för alla",
    "{actor} opened the conversation to everyone" : "{actor} öppnade konversationen för alla",
    "You opened the conversation to everyone" : "Du öppnade konversationen för alla",
    "{actor} restricted the conversation to moderators" : "{actor} begränsade konversationen till moderatorer",
    "You restricted the conversation to moderators" : "Du begränsade konversationen till moderatorer",
    "{actor} allowed guests" : "{actor} tillåter gäster",
    "You allowed guests" : "Du tillåter gäster",
    "An administrator allowed guests" : "En administratör har tillåtit gäster",
    "{actor} disallowed guests" : "{actor} tillåter inte gäster",
    "You disallowed guests" : "Du tillåter inte gäster",
    "An administrator disallowed guests" : "En administratör tillåter inte gäster",
    "{actor} set a password" : "{actor} satte ett lösenord",
    "You set a password" : "Du satte ett lösenord",
    "An administrator set a password" : "En administratör har aktiverat ett lösenord",
    "{actor} removed the password" : "{actor} tog bort lösenordet",
    "You removed the password" : "Du tog bort lösenordet",
    "An administrator removed the password" : "En administratör har tagit bort lösenordet",
    "{actor} added {user}" : "{actor} la till {user}",
    "You joined the conversation" : "Du gick med i konversationen",
    "{actor} joined the conversation" : "{actor} gick med i konversationen",
    "You added {user}" : "Du lade till {user}",
    "{actor} added you" : "{actor} lade till dig",
    "An administrator added you" : "En administratör lade till dig",
    "An administrator added {user}" : "En administratör lade till {user}",
    "You left the conversation" : "Du lämnade konversationen",
    "{actor} left the conversation" : "{actor} lämnade konversationen",
    "{actor} removed {user}" : "{actor} tog bort {user}",
    "You removed {user}" : "Du tog bort {user}",
    "{actor} removed you" : "{actor} tog bort dig",
    "An administrator removed you" : "En administratör tog bort dig",
    "An administrator removed {user}" : "En administratör tog bort {user}",
    "{actor} promoted {user} to moderator" : "{actor} gjorde {user} till moderator",
    "You promoted {user} to moderator" : "Du gjorde {user} till moderator",
    "{actor} promoted you to moderator" : "{actor} gjorde dig moderator",
    "An administrator promoted you to moderator" : "En administratör gjorde dig till moderator",
    "An administrator promoted {user} to moderator" : "En administratör gjorde {user} till moderator",
    "{actor} demoted {user} from moderator" : "{actor} tog bort {user} som moderator",
    "You demoted {user} from moderator" : "Du tog bort {user} som moderator",
    "{actor} demoted you from moderator" : "{actor} tog bort dig som moderator",
    "An administrator demoted you from moderator" : "En administratör tog bort dig som moderator",
    "An administrator demoted {user} from moderator" : "En administratör tog bort {user} som moderator",
    "{actor} shared a file which is no longer available" : "{actor} delade en fil som inte längre är tillgänglig",
    "You shared a file which is no longer available" : "Du delade en fil som inte längre är tillgänglig",
    "%s (guest)" : "%s (gäst)",
    "You missed a call from {user}" : "Du missade ett samtal från {user}",
    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Samtal med %n gäst (Varaktighet {duration})","Samtal med %n gäster (Varaktighet {duration})"],
    "Call with {user1} and {user2} (Duration {duration})" : "Samtal med {user1} och {user2} (Varade {duration})",
    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Samtal med {user1}, {user2} och {user3} (Varade {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Samtal med {user1}, {user2}, {user3} och {user4} (Varade {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Samtal med {user1}, {user2}, {user3}, {user4} och {user5} (Varade {duration})",
    "Talk to %s" : "Prata med %s",
    "File is not shared, or shared but not with the user" : "Filen delas inte eller delas men inte med användaren",
    "Talk mentions" : "Talk-omnämnanden",
    "Write to conversation" : "Skriv till konversation",
    "Writes event information into a conversation of your choice" : "Skriver händelseinformation till en konversation du väljer",
    "%s invited you to a conversation." : "%s bjöd in dig till en konversation.",
    "You were invited to a conversation." : "Du blev inbjuden till en konversation.",
    "Conversation invitation" : "Inbjudan till konversation",
    "Click the button below to join." : "Klicka på knappen nedan för att gå med.",
    "Join »%s«" : "Anslut »%s«",
    "You can also dial-in via phone with the following details" : "Det går också att ringa-upp via telefon med följande information",
    "Dial-in information" : "Uppringningsinformation",
    "Meeting ID" : "Mötes-ID",
    "Your PIN" : "Din pinkod",
    "Password request: %s" : "Lösenordsförfrågan: %s",
    "Private conversation" : "Privat konversation",
    "Deleted user (%s)" : "Raderad användare (%s)",
    "{user} in {call}" : "{user} i {call}",
    "Deleted user in {call}" : "Tog bort användare från {call}",
    "{user} sent you a private message" : "{user} skickade dig ett privat meddelande",
    "{user} sent a message in conversation {call}" : "{user} skickade ett meddelande i konversation {call}",
    "A deleted user sent a message in conversation {call}" : "En raderad användare skickade ett meddelande i konversation {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (gäst) skickade ett meddelande i konversationen {call}",
    "A guest sent a message in conversation {call}" : "En gäst skickade ett meddelande i konversation {call}",
    "{user} replied to your private message" : "{user} svarade på ditt privata meddelande",
    "{user} replied to your message in conversation {call}" : "{user} svarade på ditt meddelande i konversationen {call}",
    "A deleted user replied to your message in conversation {call}" : "En raderad användare svarade på ditt meddelande i konversationen {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (gäst) svarade på ditt meddelande i konversationen {call}",
    "A guest replied to your message in conversation {call}" : "En gäst svarade på ditt meddelande i konversationen {call}",
    "{user} mentioned you in a private conversation" : "{user} nämnde dig i en privat konversation",
    "{user} mentioned you in conversation {call}" : "{user} nämnde dig i konversation {call}",
    "A deleted user mentioned you in conversation {call}" : "En raderad användare nämnde dig i konversation {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (gäst) nämnde dig i konversationen {call}",
    "A guest mentioned you in conversation {call}" : "En gäst nämnde dig i konversation {call}",
    "View chat" : "Visa chatt",
    "{user} invited you to a private conversation" : "{user} bjöd in dig till en privat konversation",
    "Join call" : "Gå med i samtal",
    "{user} invited you to a group conversation: {call}" : "{user} bjöd in dig till en gruppkonversation: {call}",
    "Answer call" : "Svara på samtal",
    "Call back" : "Ring tillbaka",
    "A group call has started in {call}" : "Ett gruppsamtal har startats i {call}",
    "You missed a group call in {call}" : "Du missade ett gruppsamtal i {call}",
    "{email} is requesting the password to access {file}" : "{email} begär lösenordet för åtkomst till {file}",
    "{email} tried to request the password to access {file}" : "{email} försökte begära lösenordet för åtkomst till {file}",
    "Someone is requesting the password to access {file}" : "Någon begär lösenordet för att komma åt {file}",
    "Someone tried to request the password to access {file}" : "Någon försökte begära lösenordet för att komma åt {file}",
    "Open settings" : "Öppna inställningar",
    "Conversations" : "Konversationer",
    "Messages" : "Meddelanden",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Förenade arabemiraten",
    "Afghanistan" : "Afghanistan",
    "Antigua and Barbuda" : "Antigua och Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albanien",
    "Armenia" : "Armenien",
    "Angola" : "Angola",
    "Antarctica" : "Antarktis",
    "Argentina" : "Argentina",
    "American Samoa" : "Amerikanska Samoa",
    "Austria" : "Österrike",
    "Australia" : "Australien",
    "Aruba" : "Aruba",
    "Åland Islands" : "Åland",
    "Azerbaijan" : "Azerbajdzjan",
    "Bosnia and Herzegovina" : "Bosnien och Herzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgien",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgarien",
    "Bahrain" : "Bahrain",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei Darussalam" : "Brunei Darussalam",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius and Saba",
    "Brazil" : "Brasilien",
    "Bahamas" : "Bahamas",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Bouvet Island",
    "Botswana" : "Botswana",
    "Belarus" : "Vitryssland",
    "Belize" : "Belize",
    "Canada" : "Kanada",
    "Cocos (Keeling) Islands" : "Cocos (Keeling) Islands",
    "Central African Republic" : "Centralafrikanska republiken",
    "Congo" : "Kongo, Republiken (Brazzaville)",
    "Switzerland" : "Schweiz",
    "Côte d'Ivoire" : "Elfenbenskusten",
    "Cook Islands" : "Cook Islands",
    "Chile" : "Chile",
    "Cameroon" : "Kamerun",
    "China" : "Kina",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Kuba",
    "Cabo Verde" : "Kap Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Julön",
    "Cyprus" : "Cypern",
    "Czechia" : "Tjeckien",
    "Germany" : "Tyskland",
    "Djibouti" : "Djibouti",
    "Denmark" : "Danmark",
    "Dominica" : "Dominica",
    "Dominican Republic" : "Dominikanska republiken",
    "Algeria" : "Algeriet",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estland",
    "Egypt" : "Egypten",
    "Western Sahara" : "Västsahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Spanien",
    "Ethiopia" : "Etiopien",
    "Finland" : "Finland",
    "Fiji" : "Fiji",
    "Falkland Islands (Malvinas)" : "Falklandsöarna (Malvinas)",
    "Faroe Islands" : "Färöarna",
    "France" : "Frankrike",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Förenade konungariket Storbritannien och Nordirland",
    "Grenada" : "Grenada",
    "Georgia" : "Georgien",
    "French Guiana" : "Franska Guyana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Grönland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Equatorial Guinea",
    "Greece" : "Grekland",
    "South Georgia and the South Sandwich Islands" : "South Georgia and the South Sandwich Islands",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Heard Island och McDonald Islands",
    "Honduras" : "Honduras",
    "Croatia" : "Kroatien",
    "Haiti" : "Haiti",
    "Hungary" : "Ungern",
    "Indonesia" : "Indonesien",
    "Ireland" : "Irland",
    "Israel" : "Israel",
    "Isle of Man" : "Isle of Man",
    "India" : "Indien",
    "British Indian Ocean Territory" : "British Indian Ocean Territory",
    "Iraq" : "Irak",
    "Iceland" : "Island",
    "Italy" : "Italien",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordanien",
    "Japan" : "Japan",
    "Kenya" : "Kenya",
    "Kyrgyzstan" : "Kirgizistan",
    "Cambodia" : "Kambodja",
    "Kiribati" : "Kiribati",
    "Comoros" : "Comoros",
    "Saint Kitts and Nevis" : "Saint Kitts and Nevis",
    "Kuwait" : "Kuwait",
    "Cayman Islands" : "Cayman Islands",
    "Kazakhstan" : "Kazakstan",
    "Lao People's Democratic Republic" : "Lao People's Democratic Republic",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litauen",
    "Luxembourg" : "Luxemburg",
    "Latvia" : "Lettland",
    "Libya" : "Libyen",
    "Morocco" : "Marocko",
    "Monaco" : "Monaco",
    "Montenegro" : "Montenegro",
    "Saint Martin (French part)" : "Saint Martin (French part)",
    "Madagascar" : "Madagaskar",
    "Marshall Islands" : "Marshall Islands",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongoliet",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Northern Mariana Islands",
    "Martinique" : "Martinique",
    "Mauritania" : "Mauretanien",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Maldiverna",
    "Malawi" : "Malawi",
    "Mexico" : "Mexico",
    "Malaysia" : "Malaysia",
    "Mozambique" : "Mozambique",
    "Namibia" : "Namibia",
    "New Caledonia" : "Nya Kaledonien",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolk Island",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Nederländerna",
    "Norway" : "Norge",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nya Zeeland",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Franska Polynesien",
    "Papua New Guinea" : "Papua Nya Guinea",
    "Philippines" : "Filippinerna",
    "Pakistan" : "Pakistan",
    "Poland" : "Polen",
    "Saint Pierre and Miquelon" : "Saint Pierre and Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Palestine, State of" : "Palestine, State of",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Qatar",
    "Réunion" : "Réunion",
    "Romania" : "Rumänien",
    "Serbia" : "Serbien",
    "Russian Federation" : "Russian Federation",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Saudi Arabia",
    "Solomon Islands" : "Salomonöarna",
    "Seychelles" : "Seychellerna",
    "Sudan" : "Sudan",
    "Sweden" : "Sverige",
    "Singapore" : "Singapore",
    "Saint Helena, Ascension and Tristan da Cunha" : "Saint Helena, Ascension and Tristan da Cunha",
    "Slovenia" : "Slovenien",
    "Svalbard and Jan Mayen" : "Svalbard and Jan Mayen",
    "Slovakia" : "Slovakien",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Suriname" : "Surinam",
    "South Sudan" : "South Sudan",
    "Sao Tome and Principe" : "Sao Tome and Principe",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "Sint Maarten (Dutch part)",
    "Syrian Arab Republic" : "Syrian Arab Republic",
    "Turks and Caicos Islands" : "Turks- och Caicosöarna",
    "Chad" : "Chad",
    "French Southern Territories" : "Franska södra territorierna",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tadzjikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisien",
    "Tonga" : "Tonga",
    "Turkey" : "Turkiet",
    "Trinidad and Tobago" : "Trinidad och Tobago",
    "Tuvalu" : "Tuvalu",
    "Tanzania, United Republic of" : "Tanzania, United Republic of",
    "Ukraine" : "Ukraina",
    "Uganda" : "Uganda",
    "United States Minor Outlying Islands" : "United States Minor Outlying Islands",
    "United States of America" : "United States of America",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Holy See",
    "Saint Vincent and the Grenadines" : "Saint Vincent and the Grenadines",
    "Viet Nam" : "Viet Nam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis and Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Yemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Sydafrika",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Invalid date, date format must be YYYY-MM-DD" : "Felaktigt datum, datumformat måste vara ÅÅÅÅ-MM-DD",
    "Conversation not found" : "Konversationen hittades inte",
    "Path is already shared with this room" : "Sökvägen är redan delad med detta rum",
    "Chat, video & audio-conferencing using WebRTC" : "Chatt, video och ljud - konferenser med WebRTC",
    "Navigating away from the page will leave the call in {conversation}" : "Navigera bort från sidan kommer att lämna samtalet {conversation}",
    "Leave call" : "Lämna samtalet",
    "Stay in call" : "Stanna i samtal",
    "Discuss this file" : "Diskutera den här filen",
    "Share this file with others to discuss it" : "Dela den här filen med andra för att diskutera",
    "Share this file" : "Dela den här filen",
    "Join conversation" : "Gå med i konversation",
    "Request password" : "Begär lösenord",
    "Error requesting the password." : "Fel vid begäran av lösenord.",
    "This conversation has ended" : "Denna konversation har avslutats",
    "Limit to groups" : "Begränsa till grupper",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "När minst en grupp väljs kan bara personer i de angivna grupperna ingå i konversationer.",
    "Guests can still join public conversations." : "Gäster kan fortfarande delta i publika konversationer.",
    "Limit using Talk" : "Begränsa använda Talk",
    "Limit creating a public and group conversation" : "Begränsa att skapa en allmän och gruppkonversation",
    "Limit creating conversations" : "Begränsa att skapa konversationer",
    "Limit starting a call" : "Begränsa att starta ett samtal",
    "Limit starting calls" : "Begränsa att starta samtal",
    "When a call has started, everyone with access to the conversation can join the call." : "När ett samtal har startat kan alla som har åtkomst till konversationen gå med i samtalet.",
    "Everyone" : "Alla",
    "Users and moderators" : "Användare och moderatorer",
    "Moderators only" : "Endast moderatorer",
    "Save changes" : "Spara ändringar",
    "Saving …" : "Sparar ...",
    "Saved!" : "Sparat!",
    "None" : "Ingen",
    "User" : "Användare",
    "Disabled" : "Inaktiverad",
    "Moderators" : "Moderatorer",
    "Users" : "Användare",
    "Commands" : "Kommandon",
    "Beta" : "Beta",
    "Name" : "Namn",
    "Command" : "Kommando",
    "Script" : "Skript",
    "Response to" : "Svar till",
    "Enabled for" : "Aktiverad för",
    "General settings" : "Allmänna inställningar",
    "Default notification settings" : "Standardinställningar meddelanden",
    "Default group notification" : "Standard gruppmeddelande",
    "Default group notification for new groups" : "Standard gruppmeddelande för nya grupper",
    "Integration into other apps" : "Integration med andra appar",
    "Allow conversations on files" : "Tillåt konversationer på filer",
    "Allow conversations on public shares for files" : "Tillåt konversationer på offentliga delningar för filer",
    "All messages" : "Alla meddelanden",
    "@-mentions only" : "@-mentions only",
    "Off" : "Av",
    "Language" : "Språk",
    "Country" : "Land",
    "Status" : "Status",
    "Created at" : "Skapad",
    "Pending" : "Avvaktar",
    "Error" : "Fel",
    "Blocked" : "Blockerar",
    "Active" : "Aktiv",
    "Expired" : "Utgånget",
    "Shared secret" : "Delad hemlighet",
    "Validate SSL certificate" : "Validera SSL-certifikat",
    "Delete this server" : "Ta bort denna server",
    "Status: Checking connection" : "Status: Kontrollerar anslutning",
    "OK: Running version: {version}" : "OK: Kör version: {version}",
    "Error: Server did not respond with proper JSON" : "Error: Servern svarade inte med korrekt JSON",
    "Error: Server responded with: {error}" : "Error: Servern svarade med: {error}",
    "Error: Unknown error occurred" : "Error: Okänt fel inträffade",
    "Saved" : "Sparad",
    "Add a new server" : "Lägg till ny server",
    "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "En extern signalserver bör eventuellt användas för större installationer. Lämna tomt för att använda den interna signalservern.",
    "Please note that calls with more than 4 participants without external signaling server, participants can experience connectivity issues and cause high load on participating devices." : "Observera att samtal med fler än 4 deltagare utan extern signalserver kan uppleva anslutningsproblem och orsaka hög belastning på deltagande enheter.",
    "Don't warn about connectivity issues in calls with more than 4 participants" : "Varna inte om anslutningsproblem i samtal med fler än 4 deltagare",
    "STUN server URL" : "STUN-serverwebbadress",
    "STUN servers" : "STUN-servrar",
    "A STUN server is used to determine the public IP address of participants behind a router." : "En STUN-server används för att bestämma den offentliga IP-adressen av deltagare bakom en router.",
    "TURN server URL" : "TURN-serverwebbadress",
    "TURN server secret" : "TURN-server hemlighet",
    "TURN server protocols" : "TURN-server protokoll",
    "Test this server" : "Testa denna server",
    "TURN servers" : "TURN-servrar",
    "Copy link" : "Kopiera länk",
    "Waiting for others to join the call …" : "Väntar på andra ansluter sig till samtalet ...",
    "You can invite others in the participant tab of the sidebar" : "Du kan bjuda in andra på fliken deltagare i sidofältet",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Du kan bjuda in andra på fliken deltagare i sidofältet eller dela den här länken!",
    "Share this link to invite others!" : "Dela denna länk för att bjuda in andra!",
    "Conversation link copied to clipboard." : "Konversationslänk kopierad till urklipp.",
    "The link could not be copied." : "Länken kunde inte kopieras.",
    "Show your screen" : "Visa din skärm",
    "Stop screensharing" : "Stoppa skärmdelning",
    "Settings" : "Inställningar",
    "Dismiss" : "Avfärda",
    "No audio" : "Inget ljud",
    "Mute audio" : "Stäng av ljudet",
    "Unmute audio" : "Aktivera ljud",
    "No camera" : "Ingen kamera",
    "Disable video" : "Stäng av video",
    "Enable video" : "Aktivera video",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Aktivera video. Din anslutning får ett kort avbrott när du aktiverar video första gången",
    "Screensharing options" : "Skärmdelningsalternativ",
    "Enable screensharing" : "Tillåt skärmdelning",
    "Screen sharing is not supported by your browser." : "Skärmdelning stöds inte av din webbläsare.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Skärmdelning kräver att sidan läses in via HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "Skärmdelning kräver HTTPS",
    "Sharing your screen only works with Firefox version 52 or newer." : "Skärmdelning fungerar endast med Firefox version 52 eller nyare.",
    "Screensharing extension is required to share your screen." : "Skärmdelningstillägg krävs för att dela din skärm.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Vänligen använd en annan webbläsare som t.ex Firefox eller Chrome för att dela din skärm.",
    "An error occurred while starting screensharing." : "Ett fel uppstod vid skärmdelning.",
    "Back" : "Tillbaka",
    "You have been muted by a moderator" : "Du har tystats av en moderator",
    "You" : "Du",
    "Show screen" : "Visa skärm",
    "Mute" : "Tyst",
    "Stop following" : "Sluta följa",
    "You need to be logged in to upload files" : "Du måste vara inloggad för att ladda upp filer",
    "Drop your files to upload" : "Släpp dina filer för att ladda upp",
    "Call in progress" : "Samtal pågår",
    "Favorite" : "Favorit",
    "Conversation settings" : "Konversationsinställningar",
    "Chat notifications" : "Chatt-aviseringar",
    "Leave conversation" : "Lämna konversationen",
    "Delete conversation" : "Ta bort konversationen",
    "You need to promote a new moderator before you can leave the conversation." : "Du måste tilldela en ny moderator innan du kan lämna konversationen.",
    "Do you really want to delete \"{displayName}\"?" : "Vill du verkligen radera \"{displayName}\"?",
    "Password protection" : "Lösenordsskydd",
    "Enter a password" : "Ange ett lösenord",
    "Copy conversation link" : "Kopiera konversationslänk",
    "Open conversation to registered users" : "Öppna konversation för registrerade användare",
    "Enable lobby" : "Aktivera lobbyn",
    "Start time (optional)" : "Starttid (valfritt)",
    "Save" : "Spara",
    "Edit" : "Ändra",
    "Password" : "Lösenord",
    "API token" : "API-token",
    "Login" : "Logga in",
    "Nickname" : "Smeknamn",
    "Client ID" : "Klient-ID",
    "Remove from favorites" : "Ta bort från favoriter",
    "Add to favorites" : "Lägg till som favorit",
    "You: {lastMessage}" : "Du: {lastMessage}",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "No matches" : "Inga träffar",
    "Loading" : "Läser in",
    "No search results" : "Inga sökresultat",
    "Groups" : "Grupper",
    "Circles" : "Cirklar",
    "Users, groups and circles" : "Användare, grupper och cirklar",
    "Users and groups" : "Användare och grupper",
    "Users and circles" : "Användare och cirklar",
    "Groups and circles" : "Grupper och cirklar",
    "Other sources" : "Andra källor",
    "An error occurred while performing the search" : "Ett fel uppstod när sökningen utfördes",
    "Creating your conversation" : "Skapar din konversation",
    "All set" : "Allt klart",
    "Error while creating the conversation" : "Fel uppstod när konversationen skulle skapas",
    "Link copied to the clipboard!" : "Länken kopierad till urklipp!",
    "Create a new group conversation" : "Skapa en ny gruppkonversation",
    "Password protect" : "Lösenordsskydda",
    "Add participants" : "Lägg till deltagare",
    "Create conversation" : "Skapa konversation",
    "Close" : "Stäng",
    "Choose a password" : "Välj ett lösenord",
    "Search participants" : "Sök deltagare",
    "Conversation name" : "Konversationens namn",
    "Search conversations or users" : "Sök konversationer eller användare",
    "You are currently waiting in the lobby" : "Du väntar för närvarande i lobbyn",
    "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Du väntar för närvarande i lobbyn. Detta möte är planerat till {startTime}",
    "Camera" : "Kamera",
    "Reply" : "Svara",
    "Go to file" : "Gå till fil",
    "[Unknown username]" : "[Okänt användarnamn]",
    "Today" : "Idag",
    "Yesterday" : "Igår",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Share files to the conversation" : "Dela filer till konversationen",
    "Upload new files" : "Ladda upp nya filer",
    "Share from Files" : "Dela från Filer",
    "Send message" : "Skicka meddelande",
    "File to share" : "Fil att dela",
    "Write message, @ to mention someone …" : "Skriv meddelande, @ för att nämna någon ...",
    "Invalid path selected" : "Ogiltig sökväg vald",
    "moderator" : "moderator",
    "guest" : "gäst",
    "Demote from moderator" : "Degradera från moderator",
    "Promote to moderator" : "Befordra till moderator",
    "Remove participant" : "Ta bort deltagare",
    "Add users" : "Lägg till användare",
    "Add groups" : "Lägg till grupper",
    "Add emails" : "Lägg till e-post",
    "Add circles" : "Lägg till cirklar",
    "Searching …" : "Söker ...",
    "No results" : "Inga resultat",
    "Search for more users" : "Sök efter fler användare",
    "Add users, groups or circles" : "Lägg till användare, grupper eller cirklar",
    "Add users or groups" : "Lägg till användare eller grupper",
    "Add users or circles" : "Lägg till användare eller cirklar",
    "Add groups or circles" : "Lägg till grupper eller cirklar",
    "Add other sources" : "Lägg till andra källor",
    "Participants" : "Deltagare",
    "Search or add participants" : "Sök eller lägg till deltagare",
    "An error occurred while fetching the participants" : "Ett fel uppstod när deltagarna hämtades",
    "Chat" : "Chat",
    "Display name: " : "Visningsnamn:",
    "Keyboard shortcuts" : "Tangentbordsgenvägar",
    "Search" : "Sök",
    "Error while setting attachment folder" : "Fel vid inställning av mapp för bilagor",
    "Start call" : "Starta samtal",
    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk uppdaterades, du måste ladda om sidan innan du kan starta eller gå med i ett samtal.",
    "You will be able to join the call only after a moderator starts it." : "Du kommer att kunna gå med i samtalet först när en moderator startar det.",
    "Toggle fullscreen" : "Växla helskärm",
    "Rename conversation" : "Byt namn på konversation",
    "Grid view" : "Rutnätsvy",
    "Send" : "Skicka",
    "No unread mentions" : "Inga olästa omnämnanden",
    "Say hi to your friends and colleagues!" : "Säg hej till dina vänner och kollegor!",
    "Start a conversation" : "Starta en konversation",
    "Message without mention" : "Meddelande utan omnämnande",
    "Mention myself" : "Nämn mig själv",
    "Mention room" : "Nämn rum",
    "The conversation does not exist" : "Konversationen finns inte",
    "Join a conversation or start a new one!" : "Anslut till en konversation eller starta en ny!",
    "Select conversation" : "Välj konversation",
    "Link to a conversation" : "Länka till en konversation",
    "Join a conversation or start a new one" : "Anslut till en konversation eller starta en ny",
    "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk uppdaterades, ladda om sidan igen",
    "Do not disturb" : "Stör ej",
    "Away" : "Iväg",
    "Error while sharing file" : "Fel vid delning av fil",
    "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud är i underhållsläge, ladda om sidan igen",
    "Sending signaling message has failed." : "Misslyckades skicka signalmeddelande.",
    "Establishing signaling connection is taking longer than expected …" : "Det tar längre tid än förväntat att upprätta signalanslutning ...",
    "Failed to establish signaling connection. Retrying …" : "Det gick inte att upprätta signalanslutning. Försöker igen ...",
    "Default" : "Standard",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Du verkar prata med avstängd mikrofon, sätt på mikrofonen för att andra ska höra dig",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Det gick inte att upprätta en anslutning med minst en deltagare. En TURN-server kan behövas för ditt scenario. Be din administratör att ställa in en med hjälp av {linkstart}den här dokumentationen{linkend}.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Det tar längre tid än väntat. Har mediarättigheter redan beviljats (eller avvisats)? Om ja, starta om din webbläsare, eftersom ljud och video misslyckas",
    "Access to microphone & camera is only possible with HTTPS" : "Åtkomst till mikrofon och kamera är endast möjligt via HTTPS",
    "Please move your setup to HTTPS" : "Vänligen flytta din inställning till HTTPS",
    "Access to microphone & camera was denied" : "Åtkomst till mikrofon och kamera nekades",
    "WebRTC is not supported in your browser" : "WebRTC är inte kompatibelt med din webbläsare",
    "Please use a different browser like Firefox or Chrome" : "Vänligen använd en annan webbläsare som t.ex Firefox eller Chrome",
    "Error while accessing microphone & camera" : "Fel vid åtkomst till mikrofon och kamera",
    "This conversation is password-protected" : "Denna konversation är lösenordsskyddad",
    "The password is wrong. Try again." : "Lösenordet är fel. Försök igen.",
    "Specify commands the users can use in chats" : "Ange kommandon som användare kan använda i chattar",
    "TURN server" : "TURN-server",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-servern används för att tunnla trafiken för användare som sitter bakom en brandvägg.",
    "Signaling servers" : "Signalservrar",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "En extern signalserver kan eventuellt användas för större installationer. Lämna tomt för att använda den interna signalservern.",
    "%s Talk on your mobile devices" : "%s Talk på dina mobila enheter",
    "Join conversations at any time, anywhere, on any device." : "Gå med i konversationer när som helst, var som helst, på alla enheter.",
    "Android app" : "Android-app",
    "iOS app" : " iOS-app",
    "New in Talk 6" : "Nytt i Talk 6",
    "- One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- En-till-en-konversationer är nu beständiga och kan inte längre omvandlas till gruppsamtal av misstag. När en av deltagarna lämnar samtalet raderas konversationen inte längre automatiskt. Endast om båda deltagarna lämnar samtalet raderas konversationen från servern.",
    "New in Talk 7" : "Nytt i Talk 7",
    "New in Talk 8" : "Nytt i Talk 8",
    "New in Talk 9" : "Nytt i Talk 9",
    "New in Talk 10" : "Nytt i Talk 10",
    "{actor} set up Matterbridge to synchronize this conversation with other chats." : "{actor} aktiverade Matterbridge för att synkronisera denna konversation med andra chattar",
    "You set up Matterbridge to synchronize this conversation with other chats." : "Du aktiverade Matterbridge för att synkronisera denna konversation med andra chattar",
    "{user} wants to talk with you" : "{user} vill prata med dig",
    "Users that can not use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Användare som inte kan använda Talk längre kommer fortfarande att listas som deltagare i sina tidigare samtal och även deras chattmeddelanden kommer att behållas.",
    "Error: Can not connect to server" : "Error: Kan inte ansluta till server",
    "UDP and TCP" : "UDP och TCP",
    "UDP only" : "endast UDP",
    "TCP only" : "endast TCP",
    "Share whole screen" : "Dela hela skärmen",
    "Share a single window" : "Dela ett fönster",
    "Mute audio (m)" : "Ljud av (m)",
    "Unmute audio (m)" : "Ljud på (m)",
    "Disable video (v)" : "Inaktivera video (v)",
    "Enable video (v)" : "Aktivera video (v)",
    "Enable video (v) - Your connection will be briefly interrupted when enabling the video for the first time" : "Aktivera video (v) - Din anslutning får ett kort avbrott när du aktiverar videon för första gången",
    "This conversation is read only" : "Denna konversation är skrivskyddad",
    "Conversation, " : "Konversation, ",
    "Allow guests to join via link " : "Tillåt gäster att ansluta via länk",
    "Remove" : "Ta bort",
    "Enabled" : "Aktiverad",
    "Participant settings" : "Deltagarinställningar",
    "Add participants to the conversation" : "Lägg till deltagare i konversationen",
    "Share link" : "Dela länk",
    "Exit fullscreen (f)" : "Avsluta fullskärmsläge (f)",
    "Fullscreen (f)" : "Fullskärm (f)",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome or Apple Safari." : "Webbläsaren du använder stöds inte av Nextcloud Talk. Använd den senaste versionen av Mozilla Firefox, Microsoft Edge, Google Chrome eller Apple Safari.",
    "Error while uploading file" : "Fel vid uppladdning av fil",
    "{actor} set the description to \"%1$s\"" : "{actor} ändrade beskrivningen till \"%1$s\"",
    "You set the description to \"%1$s\"" : "Du ändrade beskrivningen till \"%1$s\"",
    "An administrator set the description to \"%1$s\"" : "En administratör ändrade beskrivningen till \"%1$s\""
},
"nplurals=2; plural=(n != 1);");
